import { __decorate, __param } from 'tslib';
import { Inject, ɵɵdefineInjectable, ɵɵinject, Injectable, Component, Input, NgModule } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { DOCUMENT, CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

var ThemeService = /** @class */ (function () {
    function ThemeService(document) {
        var _this = this;
        var _a;
        this._theme = new BehaviorSubject(null);
        this.loadHandler = function () { return typeof localStorage !== 'undefined' ? localStorage.getItem('theme') : null; };
        this.saveHandler = function (theme) {
            if (typeof localStorage === 'undefined') {
                return;
            }
            if (theme) {
                localStorage.setItem('theme', theme);
            }
            else {
                localStorage.removeItem('theme');
            }
        };
        this._theme.next((_a = this.savedTheme) !== null && _a !== void 0 ? _a : this.detectedTheme);
        this._theme.subscribe(function (theme) {
            if (theme) {
                document.body.setAttribute('data-theme', theme);
            }
            else {
                document.body.removeAttribute('data-theme');
            }
        });
        this._theme.subscribe(function (theme) { return _this.savedTheme = theme; });
    }
    Object.defineProperty(ThemeService.prototype, "theme$", {
        get: function () {
            return this._theme;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ThemeService.prototype, "detectedTheme", {
        get: function () {
            return typeof window !== 'undefined' && window.matchMedia('(prefers-color-scheme: dark)').matches ? 'dark' : 'light';
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ThemeService.prototype, "theme", {
        get: function () {
            return this._theme.getValue();
        },
        set: function (value) {
            this._theme.next(value);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ThemeService.prototype, "savedTheme", {
        get: function () {
            return this.loadHandler();
        },
        set: function (theme) {
            this.saveHandler(theme);
        },
        enumerable: true,
        configurable: true
    });
    ThemeService.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
    ]; };
    ThemeService.ɵprov = ɵɵdefineInjectable({ factory: function ThemeService_Factory() { return new ThemeService(ɵɵinject(DOCUMENT)); }, token: ThemeService, providedIn: "root" });
    ThemeService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(0, Inject(DOCUMENT))
    ], ThemeService);
    return ThemeService;
}());

var DarkSwitchComponent = /** @class */ (function () {
    function DarkSwitchComponent(themeService) {
        this.themeService = themeService;
    }
    DarkSwitchComponent.prototype.ngOnInit = function () {
        this.theme$ = this.themeService.theme$;
    };
    DarkSwitchComponent.ctorParameters = function () { return [
        { type: ThemeService }
    ]; };
    DarkSwitchComponent = __decorate([
        Component({
            selector: 'ng-bootstrap-darkmode-switch',
            template: "<div class=\"custom-control custom-switch\">\n  <input type=\"checkbox\" class=\"custom-control-input\" id=\"darkModeSwitch\"\n         [ngModel]=\"(theme$ | async) === 'dark'\" (ngModelChange)=\"theme$.next($event ? 'dark' : 'light')\">\n  <label class=\"custom-control-label\" for=\"darkModeSwitch\">\n    Dark Mode\n  </label>\n</div>\n",
            styles: [""]
        })
    ], DarkSwitchComponent);
    return DarkSwitchComponent;
}());

var ThemeSwitchComponent = /** @class */ (function () {
    function ThemeSwitchComponent(themeService) {
        this.themeService = themeService;
    }
    ThemeSwitchComponent.prototype.ngOnInit = function () {
        this.theme$ = this.themeService.theme$;
    };
    ThemeSwitchComponent.ctorParameters = function () { return [
        { type: ThemeService }
    ]; };
    __decorate([
        Input()
    ], ThemeSwitchComponent.prototype, "size", void 0);
    __decorate([
        Input()
    ], ThemeSwitchComponent.prototype, "style", void 0);
    ThemeSwitchComponent = __decorate([
        Component({
            selector: 'ng-bootstrap-theme-switch',
            template: "<div class=\"btn-group btn-group-toggle\"\n     [class.btn-group-sm]=\"size==='sm'\"\n     [class.btn-group-lg]=\"size==='lg'\"\n>\n  <button type=\"button\" class=\"btn btn-light\" (click)=\"theme$.next('light')\" [class.active]=\"(theme$ | async) === 'light'\">\n    <!-- https://primer.style/octicons/sun-16 -->\n    <svg *ngIf=\"style !== 'label'\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 16 16\" width=\"16\" height=\"16\" fill=\"black\"><path fill-rule=\"evenodd\" d=\"M8 10.5a2.5 2.5 0 100-5 2.5 2.5 0 000 5zM8 12a4 4 0 100-8 4 4 0 000 8zM8 0a.75.75 0 01.75.75v1.5a.75.75 0 01-1.5 0V.75A.75.75 0 018 0zm0 13a.75.75 0 01.75.75v1.5a.75.75 0 01-1.5 0v-1.5A.75.75 0 018 13zM2.343 2.343a.75.75 0 011.061 0l1.06 1.061a.75.75 0 01-1.06 1.06l-1.06-1.06a.75.75 0 010-1.06zm9.193 9.193a.75.75 0 011.06 0l1.061 1.06a.75.75 0 01-1.06 1.061l-1.061-1.06a.75.75 0 010-1.061zM16 8a.75.75 0 01-.75.75h-1.5a.75.75 0 010-1.5h1.5A.75.75 0 0116 8zM3 8a.75.75 0 01-.75.75H.75a.75.75 0 010-1.5h1.5A.75.75 0 013 8zm10.657-5.657a.75.75 0 010 1.061l-1.061 1.06a.75.75 0 11-1.06-1.06l1.06-1.06a.75.75 0 011.06 0zm-9.193 9.193a.75.75 0 010 1.06l-1.06 1.061a.75.75 0 11-1.061-1.06l1.06-1.061a.75.75 0 011.061 0z\"></path></svg>\n    <span [class.sr-only]=\"style !== 'label'\">Light</span>\n  </button>\n  <button type=\"button\" class=\"btn btn-secondary\" (click)=\"theme$.next('auto')\">\n    <!-- https://primer.style/octicons/telescope-16 -->\n    <svg *ngIf=\"style !== 'label'\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 16 16\" width=\"16\" height=\"16\" fill=\"white\"><path fill-rule=\"evenodd\" d=\"M14.184 1.143a1.75 1.75 0 00-2.502-.57L.912 7.916a1.75 1.75 0 00-.53 2.32l.447.775a1.75 1.75 0 002.275.702l11.745-5.656a1.75 1.75 0 00.757-2.451l-1.422-2.464zm-1.657.669a.25.25 0 01.358.081l1.422 2.464a.25.25 0 01-.108.35l-2.016.97-1.505-2.605 1.85-1.26zM9.436 3.92l1.391 2.41-5.42 2.61-.942-1.63 4.97-3.39zM3.222 8.157l-1.466 1a.25.25 0 00-.075.33l.447.775a.25.25 0 00.325.1l1.598-.769-.83-1.436zm6.253 2.306a.75.75 0 00-.944-.252l-1.809.87a.75.75 0 00-.293.253L4.38 14.326a.75.75 0 101.238.848l1.881-2.75v2.826a.75.75 0 001.5 0v-2.826l1.881 2.75a.75.75 0 001.238-.848l-2.644-3.863z\"></path></svg>\n    <span [class.sr-only]=\"style !== 'label'\">Auto</span>\n  </button>\n  <button type=\"button\" class=\"btn btn-dark\" (click)=\"theme$.next('dark')\" [class.active]=\"(theme$ | async) === 'dark'\">\n    <!-- https://primer.style/octicons/moon-16 -->\n    <svg *ngIf=\"style !== 'label'\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 16 16\" width=\"16\" height=\"16\" fill=\"white\"><path fill-rule=\"evenodd\" d=\"M9.598 1.591a.75.75 0 01.785-.175 7 7 0 11-8.967 8.967.75.75 0 01.961-.96 5.5 5.5 0 007.046-7.046.75.75 0 01.175-.786zm1.616 1.945a7 7 0 01-7.678 7.678 5.5 5.5 0 107.678-7.678z\"></path></svg>\n    <span [class.sr-only]=\"style !== 'label'\">Dark</span>\n  </button>\n</div>\n",
            styles: [""]
        })
    ], ThemeSwitchComponent);
    return ThemeSwitchComponent;
}());

var NgBootstrapDarkmodeModule = /** @class */ (function () {
    function NgBootstrapDarkmodeModule() {
    }
    NgBootstrapDarkmodeModule = __decorate([
        NgModule({
            declarations: [
                DarkSwitchComponent,
                ThemeSwitchComponent,
            ],
            imports: [
                CommonModule,
                FormsModule,
            ],
            exports: [
                DarkSwitchComponent,
                ThemeSwitchComponent,
            ]
        })
    ], NgBootstrapDarkmodeModule);
    return NgBootstrapDarkmodeModule;
}());

/*
 * Public API Surface of ng-bootstrap-darkmode
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DarkSwitchComponent, NgBootstrapDarkmodeModule, ThemeService, ThemeSwitchComponent };
//# sourceMappingURL=ng-bootstrap-darkmode.js.map
